@@ -7,13 +7,19 @@ class AbstractCommandHandler:
     _required_parameters_count = 0
 
     def HandleCommand(self, python_command):
-        self.iterate(python_command)
-        return self.process(python_command)
+        try:
+            self.iterate(python_command)
+            return self.process(python_command)
+        except Exception as e:
+            raise e
 
     def iterate(self, command):
         for i in range(0, len(command.payload)):
             if isinstance(command.payload[i], PythonCommand):
-                command.payload[i] = handler_dict.get(command.payload[i].command_type).HandleCommand(command.payload[i])
+                try:
+                    command.payload[i] = handler_dict.get(command.payload[i].command_type).HandleCommand(command.payload[i])
+                except Exception as e:
+                    raise e
 
     def process(self, python_command):
         pass
