@@ -14,5 +14,5 @@ class GetInstanceFieldHandler(AbstractCommandHandler):
             value = getattr(clazz, python_command.payload[1])
             return value
         except Exception as e:
-            return e
+            raise Exception(e) from e
 
