@@ -14,4 +14,4 @@ class GetStaticFieldHandler(AbstractCommandHandler):
             value = getattr(clazz, python_command.payload[1])
             return value
         except Exception as e:
-            return e
+            raise Exception(e) from e
